@@ -55,7 +55,6 @@
 
 #include <libgnome/gnome-macros.h>
 
-#include "anjuta-children.h"
 #include "anjuta-utils.h"
 #include "anjuta-marshal.h"
 #include "resources.h"
@@ -64,6 +63,7 @@
 
 #define ANJUTA_PIXMAP_PASSWORD "password.png"
 #define FILE_BUFFER_SIZE 1024
+#define FILE_INPUT_BUFFER_SIZE		1048576
 #ifndef __MAX_BAUD
 #ifdef __CYGWIN__
 #define __MAX_BAUD B256000
@@ -112,11 +112,12 @@ struct _AnjutaLauncherPriv
 	
 	/* The child */
 	pid_t child_pid;
+	guint source;
 	gint child_status;
 	gboolean child_has_terminated;
 	
 	/* Synchronization in progress */
-	gboolean in_synchronization;
+	gboolean in_cleanup;
 	guint completion_check_timeout;
 
 	/* Terminate child on child exit */
@@ -136,6 +137,10 @@ struct _AnjutaLauncherPriv
 	
 	/* Callback data */
 	gpointer callback_data;
+	
+	/* Encondig */
+	gboolean custom_encoding;
+	gchar* encoding;
 };
 
 enum
@@ -188,7 +193,7 @@ anjuta_launcher_initialize (AnjutaLauncher *obj)
 	obj->priv->child_has_terminated = TRUE;
 	
 	/* Synchronization in progress */
-	obj->priv->in_synchronization = FALSE;
+	obj->priv->in_cleanup = FALSE;
 	obj->priv->completion_check_timeout = -1;
 	
 	/* Terminate child on child exit */
@@ -203,6 +208,10 @@ anjuta_launcher_initialize (AnjutaLauncher *obj)
 	/* Output callback */
 	obj->priv->output_callback = NULL;
 	obj->priv->callback_data = NULL;
+	
+	/* Encoding */
+	obj->priv->custom_encoding = FALSE;
+	obj->priv->encoding = NULL;
 }
 
 GType
@@ -238,7 +247,8 @@ anjuta_launcher_dispose (GObject *obj)
 	if (anjuta_launcher_is_busy (launcher))
 	{
 		pid_t child_pid_save = launcher->priv->child_pid;
-		anjuta_children_unregister (child_pid_save);
+		guint child_source = launcher->priv->source;
+		g_source_remove (child_source);
 		anjuta_launcher_execution_done_cleanup (launcher, FALSE);
 		
 		/* We can not call anjuta_launcher_reset (launcher) to kill the
@@ -246,6 +256,9 @@ anjuta_launcher_dispose (GObject *obj)
 		 */
 		kill (child_pid_save, SIGTERM);
 		launcher->priv->busy = FALSE;
+		
+		if (launcher->priv->custom_encoding && launcher->priv->encoding)
+			g_free (launcher->priv->encoding);
 	}
 	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (obj));
 }
@@ -363,6 +376,28 @@ anjuta_launcher_send_stdin (AnjutaLauncher *launcher, const gchar * input_str)
 	anjuta_launcher_send_ptyin (launcher, input_str);
 }
 
+/**
+ * anjuta_launcher_send_stdin:
+ * @launcher: a #AnjutaLancher object.
+ * 
+ * Sends a EOF to Standard input of the process currently being executed.
+ */
+
+void 
+anjuta_launcher_send_stdin_eof (AnjutaLauncher *launcher)
+{
+	GError* err = NULL;
+	g_io_channel_shutdown (launcher->priv->pty_channel, TRUE,
+						   &err);
+	g_io_channel_unref (launcher->priv->pty_channel);
+	launcher->priv->pty_channel = NULL;
+	
+	if (err)
+	{
+		g_warning ("g_io_channel_shutdown () failed: %s", err->message);
+	}
+}
+
 /**
  * anjuta_launcher_send_ptyin:
  * @launcher: a #AnjutaLancher object.
@@ -446,12 +481,12 @@ anjuta_launcher_get_child_pid (AnjutaLauncher *launcher)
 static void
 anjuta_launcher_synchronize (AnjutaLauncher *launcher)
 {
+	if (launcher->priv->in_cleanup) return;
+
 	if (launcher->priv->child_has_terminated &&
 		launcher->priv->stdout_is_done &&
 		launcher->priv->stderr_is_done)
 	{
-		launcher->priv->in_synchronization = TRUE;
-		
 		if (launcher->priv->completion_check_timeout >= 0)
 			g_source_remove (launcher->priv->completion_check_timeout);
 		launcher->priv->completion_check_timeout = 
@@ -546,8 +581,9 @@ create_password_dialog (const gchar* prompt)
 static void
 anjuta_launcher_check_password_real (AnjutaLauncher *launcher,
 									 const gchar* last_line)
-{
-	if (anjuta_launcher_is_busy (launcher) == FALSE) return;
+{	
+	if (anjuta_launcher_is_busy (launcher) == FALSE) 
+		return;
 	
 	if (last_line) {
 
@@ -609,8 +645,8 @@ anjuta_launcher_check_password (AnjutaLauncher *launcher, const gchar *chars)
 static gboolean
 is_password_prompt (const gchar* line)
 {
-	gchar* password = "assword";
-	gchar* passphrase = "assphrase";
+	const gchar* password = "assword";
+	const gchar* passphrase = "assphrase";
 	
 	if (strlen (line) < strlen (password)
 		|| strlen (line) < strlen (passphrase))
@@ -714,7 +750,7 @@ anjuta_launcher_scan_output (GIOChannel *channel, GIOCondition condition,
 		do
 		{
 			g_io_channel_read_chars (channel, buffer, FILE_BUFFER_SIZE-1, &n, &err);
-			if (n > 0 && !err) /* There is output */
+			if (n > 0) /* There is output */
 			{
 				gchar *utf8_chars;
 				buffer[n] = '\0';
@@ -724,11 +760,18 @@ anjuta_launcher_scan_output (GIOChannel *channel, GIOCondition condition,
 												 utf8_chars);
 				g_free (utf8_chars);
 			}
+			/* Ignore illegal characters */
+			if (err && err->domain == G_CONVERT_ERROR)
+			{
+				g_warning ("stdout: %s", err->message);
+				g_error_free (err);
+				err = NULL;
+			}
 			/* The pipe is closed on the other side */
 			/* if not related to non blocking read or interrupted syscall */
 			else if (err && errno != EAGAIN && errno != EINTR)
 			{
-				/* DEBUG_PRINT ("launcher.c: Error while reading child stdout\n"); */
+				g_warning ("stdout: %s", err->message);
 				launcher->priv->stdout_is_done = TRUE;
 				anjuta_launcher_synchronize (launcher);
 				ret = FALSE;
@@ -741,7 +784,7 @@ anjuta_launcher_scan_output (GIOChannel *channel, GIOCondition condition,
 	}
 	if ((condition & G_IO_ERR) || (condition & G_IO_HUP))
 	{
-		/* DEBUG_PRINT ("launcher.c: STDOUT pipe closed"); */
+		DEBUG_PRINT ("launcher.c: STDOUT pipe closed");
 		launcher->priv->stdout_is_done = TRUE;
 		anjuta_launcher_synchronize (launcher);
 		ret = FALSE;
@@ -763,7 +806,7 @@ anjuta_launcher_scan_error (GIOChannel *channel, GIOCondition condition,
 		do
 		{
 			g_io_channel_read_chars (channel, buffer, FILE_BUFFER_SIZE-1, &n, &err);
-			if (n > 0 && !err) /* There is stderr output */
+			if (n > 0) /* There is stderr output */
 			{
 				gchar *utf8_chars;
 				buffer[n] = '\0';
@@ -773,11 +816,19 @@ anjuta_launcher_scan_error (GIOChannel *channel, GIOCondition condition,
 												 utf8_chars);
 				g_free (utf8_chars);
 			}
+			/* Ignore illegal characters */
+			if (err && err->domain == G_CONVERT_ERROR)
+			{
+				g_warning ("stderr: %s", err->message);
+				g_error_free (err);
+				err = NULL;
+			}
 			/* The pipe is closed on the other side */
 			/* if not related to non blocking read or interrupted syscall */
 			else if (err && errno != EAGAIN && errno != EINTR)
 			{
-				/* DEBUG_PRINT ("launcher.c: Error while reading child stderr");*/
+				g_warning ("stderr: %s", err->message);
+				
 				launcher->priv->stderr_is_done = TRUE;
 				anjuta_launcher_synchronize (launcher);
 				ret = FALSE;
@@ -790,7 +841,7 @@ anjuta_launcher_scan_error (GIOChannel *channel, GIOCondition condition,
 	}
 	if ((condition & G_IO_ERR) || (condition & G_IO_HUP))
 	{
-		/* DEBUG_PRINT ("launcher.c: STDERR pipe closed"); */
+		DEBUG_PRINT ("launcher.c: STDERR pipe closed");
 		launcher->priv->stderr_is_done = TRUE;
 		anjuta_launcher_synchronize (launcher);
 		ret = FALSE;
@@ -812,7 +863,7 @@ anjuta_launcher_scan_pty (GIOChannel *channel, GIOCondition condition,
 		do
 		{
 			g_io_channel_read_chars (channel, buffer, FILE_BUFFER_SIZE-1, &n, &err);
-			if (n > 0 && !err) /* There is stderr output */
+			if (n > 0) /* There is stderr output */
 			{
 				gchar *utf8_chars;
 				gchar *old_str = launcher->priv->pty_output_buffer;
@@ -828,11 +879,18 @@ anjuta_launcher_scan_pty (GIOChannel *channel, GIOCondition condition,
 					launcher->priv->pty_output_buffer = g_strdup (utf8_chars);
 				g_free (utf8_chars);
 			}
+			/* Ignore illegal characters */
+			if (err && err->domain == G_CONVERT_ERROR)
+			{
+				g_warning ("pty: %s", err->message);
+				g_error_free (err);
+				err = NULL;
+			}
 			/* The pipe is closed on the other side */
 			/* if not related to non blocking read or interrupted syscall */
 			else if (err && errno != EAGAIN && errno != EINTR)
 			{
-				g_warning (_("launcher.c: Error while reading child pty\n"));
+				g_warning ("pty: %s", err->message);
 				ret = FALSE;
 			}
 		/* Read next chars if buffer was too small
@@ -852,7 +910,7 @@ anjuta_launcher_scan_pty (GIOChannel *channel, GIOCondition condition,
 	/* Do not hook up for G_IO_HUP */
 	if (condition & G_IO_ERR)
 	{
-		/* DEBUG_PRINT ("launcher.c: PTY pipe error!"); */
+		DEBUG_PRINT ("launcher.c: PTY pipe error!");
 		ret = FALSE;
 	}
 	return ret;
@@ -862,18 +920,19 @@ static void
 anjuta_launcher_execution_done_cleanup (AnjutaLauncher *launcher,
 										gboolean emit_signal)
 {
-	static gboolean block = FALSE;
 	gint child_status, child_pid;
 	time_t start_time;
-	
+
+	if (launcher->priv->in_cleanup)
+		return;
+
+	launcher->priv->in_cleanup = TRUE;
+
+	/* Remove pending timeout */
 	if (launcher->priv->completion_check_timeout >= 0)
 		g_source_remove (launcher->priv->completion_check_timeout);
 	
-	if (block)
-		return;
-	
 	/* Make sure all pending I/O are flushed out */
-	block = TRUE;
 	while (g_main_context_pending (NULL))
 		g_main_context_iteration (NULL, FALSE);
 	
@@ -918,6 +977,7 @@ anjuta_launcher_execution_done_cleanup (AnjutaLauncher *launcher,
 	
 	anjuta_launcher_initialize (launcher);
 	
+	
 	/* Call this here, after set_busy (FALSE) so we are able to 
 	   launch a new child from the terminate function.
 	   (by clubfan 2002-04-07)
@@ -927,8 +987,6 @@ anjuta_launcher_execution_done_cleanup (AnjutaLauncher *launcher,
 		g_signal_emit_by_name (launcher, "child-exited", child_pid,
 							   child_status,
 							   time (NULL) - start_time);
-		
-	block = FALSE;
 }
 
 /* Using this function is necessary because
@@ -960,7 +1018,6 @@ anjuta_launcher_check_for_execution_done (gpointer data)
 	if (launcher->priv->child_has_terminated == FALSE)
 	{
 		/* DEBUG_PRINT ("launcher: We missed the exit of the child"); */
-		anjuta_children_recover();
 	}
 	launcher->priv->completion_check_timeout = -1;
 	anjuta_launcher_execution_done_cleanup (launcher, TRUE);
@@ -968,7 +1025,7 @@ anjuta_launcher_check_for_execution_done (gpointer data)
 }
 
 static void
-anjuta_launcher_child_terminated (int status, gpointer data)
+anjuta_launcher_child_terminated (GPid pid, gint status, gpointer data)
 {
 	AnjutaLauncher *launcher = data;
 	
@@ -980,24 +1037,16 @@ anjuta_launcher_child_terminated (int status, gpointer data)
 	anjuta_launcher_synchronize (launcher);
 }
 
-/**
- * anjuta_launcher_set_encoding:
- * @launcher: a #AnjutaLancher object.
- * @charset: Character set to use for Input/Output with the process.
- * 
- * Sets the character set to use for Input/Output with the process.
- *
- * Return value: TRUE if successful, otherwise FALSE.
- */
-gboolean
-anjuta_launcher_set_encoding (AnjutaLauncher *launcher, const gchar *charset)
+
+static gboolean
+anjuta_launcher_set_encoding_real (AnjutaLauncher *launcher, const gchar *charset)
 {
 	GIOStatus s;
 	gboolean r = TRUE;
 
 	g_return_val_if_fail (launcher != NULL, FALSE);
 	// charset can be NULL
-
+		
 	s = g_io_channel_set_encoding (launcher->priv->stderr_channel, charset, NULL);
 	if (s != G_IO_STATUS_NORMAL) r = FALSE;
 	s = g_io_channel_set_encoding (launcher->priv->stdout_channel, charset, NULL);
@@ -1012,6 +1061,28 @@ anjuta_launcher_set_encoding (AnjutaLauncher *launcher, const gchar *charset)
 	return r;
 }
 
+
+/**
+ * anjuta_launcher_set_encoding:
+ * @launcher: a #AnjutaLancher object.
+ * @charset: Character set to use for Input/Output with the process.
+ * 
+ * Sets the character set to use for Input/Output with the process.
+ *
+ */
+void
+anjuta_launcher_set_encoding (AnjutaLauncher *launcher, const gchar *charset)
+{
+	if (launcher->priv->custom_encoding)
+		g_free (launcher->priv->encoding);
+	
+	launcher->priv->custom_encoding = (charset != NULL);
+	if (charset)
+	  launcher->priv->encoding = g_strdup(charset);
+	else
+	  launcher->priv->encoding = NULL;		
+}
+
 static pid_t
 anjuta_launcher_fork (AnjutaLauncher *launcher, gchar *const args[])
 {
@@ -1020,7 +1091,6 @@ anjuta_launcher_fork (AnjutaLauncher *launcher, gchar *const args[])
 	int stdout_pipe[2], stderr_pipe[2];
 	pid_t child_pid;
 	struct termios termios_flags;
-	const gchar *charset;
 	
 	working_dir = g_get_current_dir ();
 	
@@ -1089,9 +1159,12 @@ anjuta_launcher_fork (AnjutaLauncher *launcher, gchar *const args[])
 	launcher->priv->stdout_channel = g_io_channel_unix_new (stdout_pipe[0]);
 	launcher->priv->pty_channel = g_io_channel_unix_new (pty_master_fd);
 
-	g_get_charset (&charset);
-	anjuta_launcher_set_encoding (launcher, charset);
+	g_io_channel_set_buffer_size (launcher->priv->pty_channel, FILE_INPUT_BUFFER_SIZE);
 
+	if (!launcher->priv->custom_encoding)
+	  g_get_charset ((const gchar**)&launcher->priv->encoding);
+	anjuta_launcher_set_encoding_real (launcher, launcher->priv->encoding);
+	
 	tcgetattr(pty_master_fd, &termios_flags);
 	termios_flags.c_iflag &= ~(IGNPAR | INPCK | INLCR | IGNCR | ICRNL | IXON |
 					IXOFF | ISTRIP);
@@ -1128,9 +1201,8 @@ anjuta_launcher_fork (AnjutaLauncher *launcher, gchar *const args[])
 						(GIOFunc)anjuta_launcher_scan_pty, launcher);
 	
 	/* DEBUG_PRINT ("Terminal child forked: %d", launcher->priv->child_pid); */
-	anjuta_children_register (launcher->priv->child_pid,
-							  anjuta_launcher_child_terminated,
-							  launcher);
+	launcher->priv->source = g_child_watch_add (launcher->priv->child_pid,
+			anjuta_launcher_child_terminated, launcher);
 	return child_pid;
 }
 
@@ -1161,7 +1233,7 @@ anjuta_launcher_execute_v (AnjutaLauncher *launcher, gchar *const argv[],
 	launcher->priv->stdout_is_done = FALSE;
 	launcher->priv->stderr_is_done = FALSE;
 	launcher->priv->child_has_terminated = FALSE;
-	launcher->priv->in_synchronization = FALSE;
+	launcher->priv->in_cleanup = FALSE;
 	launcher->priv->output_callback = callback;
 	launcher->priv->callback_data = callback_data;
 	
