@@ -15,7 +15,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 #ifndef _ANJUTA_SHELL_H
 #define _ANJUTA_SHELL_H
@@ -82,13 +82,15 @@ struct _AnjutaShellIface {
 	AnjutaProfileManager* (*get_profile_manager) (AnjutaShell *shell,
 												  GError **err);
 	
-	void (*add_widget)        (AnjutaShell  *shell,
+	void (*add_widget_full)        (AnjutaShell  *shell,
 							   GtkWidget    *widget,
 							   const char   *name,
 							   const char   *title,
 							   const char   *stock_id,
 							   AnjutaShellPlacement placement,
+							   gboolean locked,
 							   GError      **error);
+	
 	void (*remove_widget)     (AnjutaShell  *shell,
 							   GtkWidget    *widget,
 							   GError      **error);
@@ -137,6 +139,16 @@ void   anjuta_shell_add_widget      (AnjutaShell     *shell,
 									 const char      *stock_id,
 									 AnjutaShellPlacement placement,
 									 GError         **error);
+
+void   anjuta_shell_add_widget_full      (AnjutaShell     *shell,
+									 GtkWidget       *widget,
+									 const char      *name,
+									 const char      *title,
+									 const char      *stock_id,
+									 AnjutaShellPlacement placement,
+									 gboolean locked,
+									 GError         **error);
+
 void   anjuta_shell_remove_widget   (AnjutaShell     *shell,
 									 GtkWidget       *widget,
 									 GError         **error);
