@@ -14,7 +14,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 use strict;
 use Data::Dumper;
@@ -48,12 +48,10 @@ my $type_map = {
 	},
 	"gchar*" => {
 		"gtype" => "G_TYPE_STRING",
-		"assert" => "__arg__ != NULL",
 		"fail_return" => "NULL"
 	},
 	"constgchar*" => {
 		"gtype" => "G_TYPE_STRING",
-		"assert" => "__arg__ != NULL",
 		"fail_return" => "NULL"
 	},
 	"gchar" => {
@@ -124,6 +122,11 @@ my $type_map = {
 		"assert" => "G_IS_VALUE(__arg__)",
 		"fail_return" => "NULL"
 	},
+	"GError*" => {
+		"gtype" => "G_TYPE_BOXED",
+		"type" => "G_TYPE_ERROR",
+		"fail_return" => "NULL"
+	},	
 	## G_TYPE_PARAM
 	"GObject*" => {
 		"gtype" => "G_TYPE_OBJECT",
@@ -652,7 +655,7 @@ sub compile_struct
 		$not_classes->{$struct_fullname} = 1;
 		
 		# Add to $type_map
-		print "haha struct $struct_fullname\n";
+		## print "haha struct $struct_fullname\n";
 		$type_map_item_hr->{'gtype'} = 'G_TYPE_POINTER';
 		$type_map_item_hr->{'rettype'} = 'NULL';
 		$type_map_item_hr->{'type'} = "G_TYPE_POINTER";
@@ -667,7 +670,7 @@ sub generate_files
 	foreach my $c (sort keys %$data_hr)
 	{
 		my $parent = $data_hr->{$c}->{'__parent'};
-		print "Generating Interface $c";
+		print "Evaluating Interface $c";
 		if ($parent ne '') {
 			print ": $parent";
 		}
@@ -675,6 +678,7 @@ sub generate_files
 		generate_class($c, $data_hr->{$c});
 	}
 	write_marshallers();
+	write_header();
 	write_makefile();
 }
 
@@ -719,6 +723,26 @@ sub get_arg_type_info
 	}
 }
 
+sub get_return_type_val
+{
+	my ($rettype) = @_;
+	my $fail_ret = get_arg_type_info($rettype, "fail_return");
+	if (!defined($fail_ret) || $fail_ret eq "")
+	{
+		## Return NULL for pointer types
+		if ($rettype =~ /\*$/ ||
+			$rettype =~ /gpointer/)
+		{
+			$fail_ret = "NULL";
+		}
+		else
+		{
+			$fail_ret = "0";
+		}
+	}
+	return $fail_ret;
+}
+
 sub get_arg_assert
 {
 	my ($rettype, $type_arg, $force) = @_;
@@ -747,6 +771,11 @@ sub get_arg_assert
 				return "";
 			}
 		}
+		# Correctly handle pointers to points (e.g AnjutaType** xy)
+		if ($saved_type =~ /\*\*$/)
+		{
+			return "";
+		}
 		## Autodetect type assert
 		if ($force ||
 			(($saved_type =~ /\*$/) &&
@@ -778,20 +807,7 @@ sub get_arg_assert
 	}
 	else
 	{
-		my $fail_ret = get_arg_type_info($rettype, "fail_return");
-		if (!defined($fail_ret) || $fail_ret eq "")
-		{
-			## Return NULL for pointer types
-			if ($rettype =~ /\*$/ ||
-				$rettype =~ /gpointer/)
-			{
-				$fail_ret = "NULL";
-			}
-			else
-			{
-				$fail_ret = "0";
-			}
-		}
+		my $fail_ret = get_return_type_val ($rettype);
 		if (defined($fail_ret))
 		{
 			$ainfo =~ s/__arg__/$arg/;
@@ -856,6 +872,52 @@ sub construct_marshaller
 	return $marshal_index.",\n\t\t\t".$args_list;
 }
 
+sub convert_ret
+{
+	my ($ret) = @_;
+	
+	if ($ret =~ /const List<.*>/)
+	{
+		return "const GList*";
+	}
+	elsif ($ret =~ /List<.*>/)
+	{
+		return "GList*";
+	}
+	else
+	{
+		return $ret;
+	}
+}
+
+sub convert_args
+{
+	my ($args) = @_;
+	my @argsv = split(',', $args);
+	foreach my $arg (@argsv)
+	{
+		if ($arg =~ /const List<.*>.*/)
+		{
+			my @arg_name = split(' ', $arg);
+			$arg = join(' ',"const GList*", $arg_name[-1]);
+		}
+		elsif ($arg =~ /.*List<.*>.*/)
+		{
+			my @arg_name = split(' ', $arg);
+			$arg = join(' ', "GList*", $arg_name[-1]);
+		}
+	}
+	$args = join(', ', @argsv);
+	return $args;
+}
+
+sub enum_split
+{
+	(my $e) = @_;
+	$e = substr($e, 0, 1) . "_" . substr($e, 1);
+	return $e;
+}
+
 sub generate_class
 {
 	my ($class, $class_hr) = @_;
@@ -914,7 +976,7 @@ sub generate_class
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef _${macro_name}_H_
@@ -946,8 +1008,11 @@ G_BEGIN_DECLS
 	{
 		foreach my $e (sort keys %$enums_hr)
 		{
-			my $e_upper = uc($e);
-			my $e_lower = lc($e);
+			# add an underscore if necassery
+			my $se = $e;
+			$se =~ s/[a-z][A-Z]/enum_split($&)/e;
+			my $e_upper = uc($se);
+			my $e_lower = lc($se);
 			my $e_macro = "${macro_type}_${e_upper}";
 			my $e_proto = "${prefix}_${e_lower}_get_type";
 			$answer .=
@@ -1017,12 +1082,14 @@ struct _${class}Iface {
 		my $func = $class_hr->{$m}->{'function'};
 		my $rettype = normalize_namespace($class, $class_hr->{$m}->{'rettype'});
 		my $args = normalize_namespace($class, $class_hr->{$m}->{'args'});
+		$args = convert_args($args);
 		if ($args ne '')
 		{
 			$args = ", ".$args;
 		}
 		if ($func =~ s/^\:\://)
 		{
+			$rettype = convert_ret($rettype);
 			$answer .= "\t/* Signal */\n";
 			$answer .= "\t$rettype (*$func) ($class *obj${args});\n";
 		}
@@ -1034,12 +1101,14 @@ struct _${class}Iface {
 		my $func = $class_hr->{$m}->{'function'};
 		my $rettype = normalize_namespace($class, $class_hr->{$m}->{'rettype'});
 		my $args = normalize_namespace($class, $class_hr->{$m}->{'args'});
+		$args = convert_args($args);
 		if ($args ne '')
 		{
 			$args .= ", ";
 		}
 		if ($func !~ /^\:\:/)
 		{
+			$rettype = convert_ret($rettype);
 			$answer .= "\t$rettype (*$func) ($class *obj, ${args}GError **err);\n";
 		}
 	}
@@ -1052,7 +1121,10 @@ struct _${class}Iface {
 	{
 		foreach my $e (sort keys %$enums_hr)
 		{
-			my $e_lower = lc($e);
+			# add an underscore if necassery
+			my $se = $e;
+			$se =~ s/[a-z][A-Z]/enum_split($&)/e;
+			my $e_lower = lc($se);
 			my $e_proto = "${prefix}_${e_lower}_get_type";
 			$answer .=
 "GType $e_proto (void);
@@ -1072,12 +1144,14 @@ GType  ${prefix}_get_type        (void);
 		my $func = $class_hr->{$m}->{'function'};
 		my $rettype = normalize_namespace($class, $class_hr->{$m}->{'rettype'});
 		my $args = normalize_namespace($class, $class_hr->{$m}->{'args'});
+		$args = convert_args($args);
 		if ($args ne '')
 		{
 			$args .= ", ";
 		}
 		if ($func !~ /^\:\:/)
 		{
+			$rettype = convert_ret($rettype);
 			$answer .= "${rettype} ${prefix}_$func ($class *obj, ${args}GError **err);\n\n";
 		}
 	}
@@ -1115,9 +1189,14 @@ G_END_DECLS
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+";
+	# Added class (section) comments
+	$answer .= $class_hr->{"__comments"};
+	$answer .=
+"
 #include \"$headerfile\"
 #include \"$module_name-iface-marshallers.h\"
 
@@ -1145,6 +1224,7 @@ ${prefix}_error_quark (void)
 
 		my $asserts = "\t".get_arg_assert($rettype, "$class *obj", 1)."\n";
 		## self assert;
+		$args = convert_args($args);
 		if ($args ne '')
 		{
 			my @params;
@@ -1165,11 +1245,13 @@ ${prefix}_error_quark (void)
 			$params .= ", ";
 		}
 		
+		$args = convert_args($args);
 		if ($args ne '')
 		{
 			$args .= ", ";
 		}
 		my $comments_out = $class_hr->{$m}->{'__comments'};
+		$rettype = convert_ret($rettype);
 		$answer .= "${comments_out}${rettype}\n${prefix}_$func ($class *obj, ${args}GError **err)\n";
 		$answer .= "{\n";
 		if ($asserts ne "")
@@ -1182,13 +1264,33 @@ ${prefix}_error_quark (void)
 		}
 		$answer .= "${macro_name}_GET_IFACE (obj)->$func (obj, ${params}err);";
 		$answer .="\n}\n\n";
+
+		## Default implementation
+		$answer .= "/* Default implementation */\n";
+		$answer .= "static ${rettype}\n${prefix}_${func}_default ($class *obj, ${args}GError **err)\n";
+		$answer .= "{\n";
+		if ($rettype ne "void") {
+			$answer .= "\tg_return_val_if_reached (". get_return_type_val($rettype). ");";
+		} else {
+			$answer .= "\tg_return_if_reached ();";
+		}
+		$answer .="\n}\n\n";
 	}
 	$answer .=
 "static void
-${prefix}_base_init (gpointer gclass)
+${prefix}_base_init (${class}Iface* klass)
 {
 	static gboolean initialized = FALSE;
-	
+
+";
+	foreach my $m (sort keys %$class_hr)
+	{
+		next if ($m =~ /^__/);
+		my $func = $class_hr->{$m}->{'function'};
+		next if ($func =~ /^\:\:/);
+		$answer .= "\tklass->$func = ${prefix}_${func}_default;\n";
+	}
+	$answer .= "	
 	if (!initialized) {
 ";
 	foreach my $m (sort keys %$class_hr)
@@ -1197,6 +1299,7 @@ ${prefix}_base_init (gpointer gclass)
 		my $func = $class_hr->{$m}->{'function'};
 		my $rettype = normalize_namespace($class, $class_hr->{$m}->{'rettype'});
 		my $args = normalize_namespace($class, $class_hr->{$m}->{'args'});
+		$args = convert_args($args);
 		if ($args ne '')
 		{
 			$args = ", ".$args;
@@ -1230,7 +1333,7 @@ ${prefix}_get_type (void)
 	if (!type) {
 		static const GTypeInfo info = {
 			sizeof (${class}Iface),
-			${prefix}_base_init,
+			(GBaseInitFunc) ${prefix}_base_init,
 			NULL, 
 			NULL,
 			NULL,
@@ -1250,7 +1353,10 @@ ${prefix}_get_type (void)
 	{
 		foreach my $e (sort keys %$enums_hr)
 		{
-			my $e_lower = lc($e);
+			# add an underscore if necassery
+			my $se = $e;
+			$se =~ s/[a-z][A-Z]/enum_split($&)/e;
+			my $e_lower = lc($se);
 			$answer .=
 "
 GType
@@ -1312,6 +1418,23 @@ sub write_marshallers
 	}
 }
 
+sub write_header
+{
+	my $iface_headers = "";
+	my $answer = 
+"
+/* Interfaces global include file */
+
+";
+;
+    foreach my $h (@header_files)
+    {
+    	$answer .= "#include \"$h\"\n";
+	}
+    write_file("libanjuta-interfaces.h", $answer);
+    push(@header_files, "libanjuta-interfaces.h");
+}
+
 sub write_makefile
 {
     my $iface_headers = "";
@@ -1325,12 +1448,12 @@ sub write_makefile
 	$iface_sources .= "\\\n\t$s";
     }
     
-    my $iface_rules = "lib_LTLIBRARIES = $module_name-interfaces.la\n";
+    my $iface_rules = "noinst_LTLIBRARIES = $module_name-interfaces.la\n";
     $iface_rules .= "${module_name}_interfaces_la_LIBADD = \$(MODULE_LIBS)\n";
 ##    $iface_rules .= "${module_name}_interfaces_la_LIBADD = \n";
     $iface_rules .= "${module_name}_interfaces_la_SOURCES = $iface_sources\n";
     $iface_rules .= "${module_name}_interfaces_includedir = \$(MODULE_INCLUDEDIR)\n";
-    $iface_rules .= "${module_name}_interfaces_include_HEADERS = $iface_headers\n";
+    $iface_rules .= "${module_name}_interfaces_include = $iface_headers\n";
     
     my $contents = `cat Makefile.am.iface`;
     $contents =~ s/\@\@IFACE_RULES\@\@/$iface_rules/;
