@@ -50,10 +50,10 @@
 /* VOID:OBJECT,OBJECT (eggmarshalers.list:1) */
 void
 _egg_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
-                                  GValue       *return_value,
+                                  GValue       *return_value G_GNUC_UNUSED,
                                   guint         n_param_values,
                                   const GValue *param_values,
-                                  gpointer      invocation_hint,
+                                  gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_OBJECT) (gpointer     data1,
@@ -87,10 +87,10 @@ _egg_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
 /* VOID:OBJECT,STRING,LONG,LONG (eggmarshalers.list:2) */
 void
 _egg_marshal_VOID__OBJECT_STRING_LONG_LONG (GClosure     *closure,
-                                            GValue       *return_value,
+                                            GValue       *return_value G_GNUC_UNUSED,
                                             guint         n_param_values,
                                             const GValue *param_values,
-                                            gpointer      invocation_hint,
+                                            gpointer      invocation_hint G_GNUC_UNUSED,
                                             gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_STRING_LONG_LONG) (gpointer     data1,
@@ -128,10 +128,10 @@ _egg_marshal_VOID__OBJECT_STRING_LONG_LONG (GClosure     *closure,
 /* VOID:OBJECT,LONG (eggmarshalers.list:3) */
 void
 _egg_marshal_VOID__OBJECT_LONG (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_LONG) (gpointer     data1,
@@ -165,10 +165,10 @@ _egg_marshal_VOID__OBJECT_LONG (GClosure     *closure,
 /* VOID:OBJECT,STRING,STRING (eggmarshalers.list:4) */
 void
 _egg_marshal_VOID__OBJECT_STRING_STRING (GClosure     *closure,
-                                         GValue       *return_value,
+                                         GValue       *return_value G_GNUC_UNUSED,
                                          guint         n_param_values,
                                          const GValue *param_values,
-                                         gpointer      invocation_hint,
+                                         gpointer      invocation_hint G_GNUC_UNUSED,
                                          gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_STRING_STRING) (gpointer     data1,
@@ -204,10 +204,10 @@ _egg_marshal_VOID__OBJECT_STRING_STRING (GClosure     *closure,
 /* VOID:UINT,UINT (eggmarshalers.list:5) */
 void
 _egg_marshal_VOID__UINT_UINT (GClosure     *closure,
-                              GValue       *return_value,
+                              GValue       *return_value G_GNUC_UNUSED,
                               guint         n_param_values,
                               const GValue *param_values,
-                              gpointer      invocation_hint,
+                              gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UINT_UINT) (gpointer     data1,
@@ -241,10 +241,10 @@ _egg_marshal_VOID__UINT_UINT (GClosure     *closure,
 /* BOOLEAN:INT (eggmarshalers.list:6) */
 void
 _egg_marshal_BOOLEAN__INT (GClosure     *closure,
-                           GValue       *return_value,
+                           GValue       *return_value G_GNUC_UNUSED,
                            guint         n_param_values,
                            const GValue *param_values,
-                           gpointer      invocation_hint,
+                           gpointer      invocation_hint G_GNUC_UNUSED,
                            gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__INT) (gpointer     data1,
@@ -280,10 +280,10 @@ _egg_marshal_BOOLEAN__INT (GClosure     *closure,
 /* BOOLEAN:ENUM (eggmarshalers.list:7) */
 void
 _egg_marshal_BOOLEAN__ENUM (GClosure     *closure,
-                            GValue       *return_value,
+                            GValue       *return_value G_GNUC_UNUSED,
                             guint         n_param_values,
                             const GValue *param_values,
-                            gpointer      invocation_hint,
+                            gpointer      invocation_hint G_GNUC_UNUSED,
                             gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__ENUM) (gpointer     data1,
@@ -319,10 +319,10 @@ _egg_marshal_BOOLEAN__ENUM (GClosure     *closure,
 /* BOOLEAN:VOID (eggmarshalers.list:8) */
 void
 _egg_marshal_BOOLEAN__VOID (GClosure     *closure,
-                            GValue       *return_value,
+                            GValue       *return_value G_GNUC_UNUSED,
                             guint         n_param_values,
                             const GValue *param_values,
-                            gpointer      invocation_hint,
+                            gpointer      invocation_hint G_GNUC_UNUSED,
                             gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer     data1,
@@ -356,10 +356,10 @@ _egg_marshal_BOOLEAN__VOID (GClosure     *closure,
 /* OBJECT:VOID (eggmarshalers.list:9) */
 void
 _egg_marshal_OBJECT__VOID (GClosure     *closure,
-                           GValue       *return_value,
+                           GValue       *return_value G_GNUC_UNUSED,
                            guint         n_param_values,
                            const GValue *param_values,
-                           gpointer      invocation_hint,
+                           gpointer      invocation_hint G_GNUC_UNUSED,
                            gpointer      marshal_data)
 {
   typedef GObject* (*GMarshalFunc_OBJECT__VOID) (gpointer     data1,
@@ -395,10 +395,10 @@ _egg_marshal_OBJECT__VOID (GClosure     *closure,
 /* VOID:INT,INT (eggmarshalers.list:11) */
 void
 _egg_marshal_VOID__INT_INT (GClosure     *closure,
-                            GValue       *return_value,
+                            GValue       *return_value G_GNUC_UNUSED,
                             guint         n_param_values,
                             const GValue *param_values,
-                            gpointer      invocation_hint,
+                            gpointer      invocation_hint G_GNUC_UNUSED,
                             gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer     data1,
@@ -436,10 +436,10 @@ _egg_marshal_VOID__INT_INT (GClosure     *closure,
 /* VOID:OBJECT,ENUM,BOXED (eggmarshalers.list:14) */
 void
 _egg_marshal_VOID__OBJECT_ENUM_BOXED (GClosure     *closure,
-                                      GValue       *return_value,
+                                      GValue       *return_value G_GNUC_UNUSED,
                                       guint         n_param_values,
                                       const GValue *param_values,
-                                      gpointer      invocation_hint,
+                                      gpointer      invocation_hint G_GNUC_UNUSED,
                                       gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_ENUM_BOXED) (gpointer     data1,
@@ -477,10 +477,10 @@ _egg_marshal_VOID__OBJECT_ENUM_BOXED (GClosure     *closure,
 /* BOOLEAN:BOOLEAN (eggmarshalers.list:16) */
 void
 _egg_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
-                               GValue       *return_value,
+                               GValue       *return_value G_GNUC_UNUSED,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__BOOLEAN) (gpointer     data1,
@@ -516,10 +516,10 @@ _egg_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
 /* BOOLEAN:OBJECT,STRING,STRING (eggmarshalers.list:17) */
 void
 _egg_marshal_BOOLEAN__OBJECT_STRING_STRING (GClosure     *closure,
-                                            GValue       *return_value,
+                                            GValue       *return_value G_GNUC_UNUSED,
                                             guint         n_param_values,
                                             const GValue *param_values,
-                                            gpointer      invocation_hint,
+                                            gpointer      invocation_hint G_GNUC_UNUSED,
                                             gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__OBJECT_STRING_STRING) (gpointer     data1,
