@@ -154,7 +154,7 @@ build_indicator_location_set (BuildIndicatorLocation *loc,
 							  IAnjutaEditor *editor,
 							  const gchar *editor_filename)
 {
-	gint line_start, line_end;
+	IAnjutaIterable *line_start, *line_end;
 	
 	if (editor && editor_filename &&
 		IANJUTA_IS_INDICABLE (editor) &&
@@ -162,14 +162,18 @@ build_indicator_location_set (BuildIndicatorLocation *loc,
 		strcmp (editor_filename, loc->filename) == 0)
 	{
 		DEBUG_PRINT ("loc line: %d", loc->line);
-	
+		
 		line_start = ianjuta_editor_get_line_begin_position (editor,
 															 loc->line, NULL);
+		
 		line_end = ianjuta_editor_get_line_end_position (editor,
 														 loc->line, NULL);
 		ianjuta_indicable_set (IANJUTA_INDICABLE (editor),
 							   line_start, line_end, loc->indicator,
 							   NULL);
+		
+		g_object_unref (line_start);
+		g_object_unref (line_end);
 	}
 }
 
@@ -559,7 +563,11 @@ on_build_mesg_format (IAnjutaMessageView *view, const gchar *one_line,
 	if ((sscanf (one_line, _("make[%d]: Entering directory '%s'"), &dummy_int, dir) == 2) ||
 		(sscanf (one_line, _("make: Entering directory '%s'"), dir) == 1) ||
 		(sscanf (one_line, _("make[%d]: Entering directory `%s'"), &dummy_int, dir) == 2) ||
-		(sscanf (one_line, _("make: Entering directory `%s'"), dir) == 1))
+		(sscanf (one_line, _("make: Entering directory `%s'"), dir) == 1) ||
+		(sscanf (one_line, "make[%d]: Entering directory '%s'", &dummy_int, dir) == 2) ||
+		(sscanf (one_line, "make: Entering directory '%s'", dir) == 1) ||
+		(sscanf (one_line, "make[%d]: Entering directory `%s'", &dummy_int, dir) == 2) ||
+		(sscanf (one_line, "make: Entering directory `%s'", dir) == 1))
 	{
 		gchar* summary;
 		/* FIXME: Hack to remove the last ' */
@@ -581,7 +589,12 @@ on_build_mesg_format (IAnjutaMessageView *view, const gchar *one_line,
 	if ((sscanf (one_line, _("make[%d]: Leaving directory '%s'"), &dummy_int, dir) == 2) ||
 		(sscanf (one_line, _("make: Leaving directory '%s'"), dir) == 1) ||
 		(sscanf (one_line, _("make[%d]: Leaving directory `%s'"), &dummy_int, dir) == 2) ||
-		(sscanf (one_line, _("make: Leaving directory `%s'"), dir) == 1))
+		(sscanf (one_line, _("make: Leaving directory `%s'"), dir) == 1) ||
+		(sscanf (one_line, "make[%d]: Leaving directory '%s'", &dummy_int, dir) == 2) ||
+		(sscanf (one_line, "make: Leaving directory '%s'", dir) == 1) ||
+		(sscanf (one_line, "make[%d]: Leaving directory `%s'", &dummy_int, dir) == 2) ||
+		(sscanf (one_line, "make: Leaving directory `%s'", dir) == 1))
+
 	{
 		gchar* summary;
 		/* FIXME: Hack to remove the last ' */
@@ -715,6 +728,7 @@ on_build_mesg_parse (IAnjutaMessageView *view, const gchar *line,
 	if (parse_error_line (line, &filename, &lineno))
 	{
 		IAnjutaDocumentManager *docman;
+		gchar *uri;
 		
 		/* Go to file and line number */
 		docman = anjuta_shell_get_interface (context->plugin->shell,
@@ -722,8 +736,13 @@ on_build_mesg_parse (IAnjutaMessageView *view, const gchar *line,
 											 NULL);
 		
 		/* Full path is detected from parse_error_line() */
-		ianjuta_document_manager_goto_file_line_mark(docman, filename, lineno, TRUE, NULL);
+		uri = gnome_vfs_get_uri_from_local_path(filename);
 		g_free(filename);
+		if (uri)
+		{
+			ianjuta_document_manager_goto_uri_line_mark(docman, uri, lineno, TRUE, NULL);
+			g_free(uri);
+		}
 	}
 }
 
@@ -802,6 +821,8 @@ build_get_context (BasicAutotoolsPlugin *plugin, const gchar *dir,
 	build_regex_init();
 
 	subdir = g_path_get_basename (dir);
+	/* Translators: the first number is the number of the build attemp,
+	   the string is the directory where the build takes place */
 	snprintf (mname, 128, _("Build %d: %s"), ++message_pane_count, subdir);
 	g_free (subdir);
 	
@@ -1043,6 +1064,7 @@ build_configure_project (GtkAction *action, BasicAutotoolsPlugin *plugin)
 	gchar *input = NULL;
 	
 	parent = GTK_WINDOW (ANJUTA_PLUGIN(plugin)->shell);
+	/* Configure = ./configure script */
 	response = anjuta_util_dialog_input (parent, _("Configure Parameters:"),
 										 plugin->configure_args, &input);
 	if (response)
@@ -1894,11 +1916,12 @@ on_editor_destroy (IAnjutaEditor *editor, BasicAutotoolsPlugin *ba_plugin)
 }
 
 static void
-on_editor_changed (IAnjutaEditor *editor, gint position, gboolean added,
-				   gint length, gint lines, const gchar *text,
+on_editor_changed (IAnjutaEditor *editor, IAnjutaIterable *position,
+				   gboolean added, gint length, gint lines, const gchar *text,
 				   BasicAutotoolsPlugin *ba_plugin)
 {
-	gint line, begin_pos, end_pos;
+	gint line;
+	IAnjutaIterable *begin_pos, *end_pos;
 	if (g_hash_table_lookup (ba_plugin->editors_created,
 							 editor) == NULL)
 		return;
@@ -1911,9 +1934,11 @@ on_editor_changed (IAnjutaEditor *editor, gint position, gboolean added,
 		ianjuta_indicable_set (IANJUTA_INDICABLE (editor), begin_pos,
 							   end_pos, IANJUTA_INDICABLE_NONE, NULL);
 	}
-	DEBUG_PRINT ("Editor changed: position = %d, added = %d,"
-				 " length = %d, lines = %d, text = \'%s\'",
-				 position, added, length, lines, text);
+	DEBUG_PRINT ("Editor changed: line number = %d, added = %d,"
+				 " text length = %d, number of lines = %d",
+				 line, added, length, lines);
+	g_object_unref (begin_pos);
+	g_object_unref (end_pos);
 }
 
 static void
