@@ -15,17 +15,18 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef __BUILD_BASIC_AUTOTOOLS_H__
 #define __BUILD_BASIC_AUTOTOOLS_H__
 
 #include <libanjuta/anjuta-plugin.h>
+#include <libanjuta/interfaces/ianjuta-buildable.h>
 
 #define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-build-basic-autotools-plugin.glade"
 
-extern GType basic_autotools_plugin_get_type (AnjutaGluePlugin *plugin);
+extern GType basic_autotools_plugin_get_type (GTypeModule *module);
 #define ANJUTA_TYPE_PLUGIN_BASIC_AUTOTOOLS         (basic_autotools_plugin_get_type (NULL))
 #define ANJUTA_PLUGIN_BASIC_AUTOTOOLS(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), ANJUTA_TYPE_PLUGIN_BASIC_AUTOTOOLS, BasicAutotoolsPlugin))
 #define ANJUTA_PLUGIN_BASIC_AUTOTOOLS_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k), ANJUTA_TYPE_PLUGIN_BASIC_AUTOTOOLS, BasicAutotoolsPluginClass))
@@ -60,6 +61,9 @@ struct _BasicAutotoolsPlugin{
 	GtkActionGroup *build_action_group;
 	GtkActionGroup *build_popup_action_group;
 	
+	/* commands overrides */
+	gchar *commands[IANJUTA_BUILDABLE_N_COMMANDS];
+	
 	/* Build parameters */
 	gchar *configure_args;
 	
