@@ -253,14 +253,15 @@ breakpoint_item_new_from_uri (BreakpointsDBase *bd, const gchar* uri, guint line
 {
 	BreakpointItem *bi;
 	
-	g_return_val_if_fail (uri != NULL, NULL);
-
 	bi = breakpoint_item_new (bd);
 	
-	bi->uri = g_strdup (uri);
 	bi->bp.type = IANJUTA_DEBUGGER_BREAKPOINT_ON_LINE | IANJUTA_DEBUGGER_BREAKPOINT_WITH_ENABLE;
-	bi->bp.file = gnome_vfs_get_local_path_from_uri (uri);
-	bi->bp.line = line;
+	if (uri != NULL)
+	{
+		bi->uri = g_strdup (uri);
+		bi->bp.file = gnome_vfs_get_local_path_from_uri (uri);
+		bi->bp.line = line;
+	}
 	bi->bp.enable = enable;
 	
 	return bi;
@@ -318,7 +319,10 @@ breakpoint_item_new_from_string (BreakpointsDBase *bd, const gchar* string, cons
 				bi->bp.type = IANJUTA_DEBUGGER_BREAKPOINT_ON_FUNCTION;
 			}
 			bi->bp.file = g_strndup (string, ptr - string);
-			bi->uri = gnome_vfs_get_uri_from_local_path (bi->bp.file);
+			if (g_path_is_absolute (bi->bp.file))
+			{
+				bi->uri = gnome_vfs_get_uri_from_local_path (bi->bp.file);
+			}
 		}
 	}
 	
@@ -398,7 +402,7 @@ breakpoints_dbase_update_in_treeview (BreakpointsDBase *bd, BreakpointItem *bi)
 	const gchar *filename;
 	const gchar *format;
 
-	adr = g_strdup_printf ("0x%x", bi->bp.address);
+	adr = g_strdup_printf ("0x%lx", bi->bp.address);
 	if (bi->bp.file != NULL)
 	{
 		filename = strrchr(bi->bp.file, G_DIR_SEPARATOR);
@@ -579,7 +583,7 @@ breakpoints_dbase_set_all_in_editor (BreakpointsDBase* bd, IAnjutaEditor* te)
 		
 			gtk_tree_model_get (model, &iter, DATA_COLUMN, &bi, -1);
 
-			if ((bi->editor == NULL) && (strcmp (uri, bi->uri) == 0))
+			if ((bi->editor == NULL) && (bi->uri != NULL) && (strcmp (uri, bi->uri) == 0))
 			{
 				bi->editor = te;
 				bi->handle = -1;
@@ -746,6 +750,7 @@ breakpoints_dbase_add_in_debugger (BreakpointsDBase *bd, BreakpointItem *bi)
 		breakpoint_item_ref (bi);
 		ok = dma_queue_add_breakpoint_at_line (
 					bd->debugger,
+					&(bi->bp.id),											   
 					bi->bp.file,
 					bi->bp.line,
 					on_breakpoint_callback,
@@ -756,6 +761,7 @@ breakpoints_dbase_add_in_debugger (BreakpointsDBase *bd, BreakpointItem *bi)
 		breakpoint_item_ref (bi);
 		ok = dma_queue_add_breakpoint_at_function (
 					bd->debugger,
+					&(bi->bp.id),											   
 					bi->bp.file == NULL ? "" : bi->bp.file,
 					bi->bp.function,
 					on_breakpoint_callback,
@@ -767,6 +773,7 @@ breakpoints_dbase_add_in_debugger (BreakpointsDBase *bd, BreakpointItem *bi)
 		breakpoint_item_ref (bi);
 		ok = dma_queue_add_breakpoint_at_address (
 					bd->debugger,
+					&(bi->bp.id),											   
 					bi->bp.address,
 					on_breakpoint_callback,
 					bi);
@@ -1004,7 +1011,7 @@ breakpoints_dbase_add_breakpoint (BreakpointsDBase *bd,  BreakpointItem *bi)
 		gchar *uri;
 		
 		uri = ianjuta_file_get_uri (IANJUTA_FILE (ed), NULL);
-		if ((uri != NULL) && (strcmp (uri, bi->uri) == 0))
+		if ((uri != NULL) && (bi->uri != NULL) && (strcmp (uri, bi->uri) == 0))
 		{
 			bi->editor = ed;
 			bi->handle = -1;
@@ -1168,7 +1175,7 @@ breakpoints_dbase_find_breakpoint_from_line (BreakpointsDBase *bd, const gchar*
 		
 			gtk_tree_model_get (model, &iter, DATA_COLUMN, &bi, -1);
 			
-			if ((line == bi->bp.line) && (strcmp (uri, bi->uri) == 0)) return bi;
+			if ((line == bi->bp.line) && (bi->uri != NULL) && (strcmp (uri, bi->uri) == 0)) return bi;
 		} while (gtk_tree_model_iter_next (model, &iter));
 	}
 	
@@ -1418,15 +1425,18 @@ breakpoints_dbase_edit_breakpoint (BreakpointsDBase *bd, BreakpointItem *bi)
 	pass_entry = glade_xml_get_widget (gxml, "breakpoint_pass_entry");
 	pass_label = glade_xml_get_widget (gxml, "breakpoint_pass_label");
 
-	if (!dma_debugger_queue_is_supported(bd->debugger, HAS_IGNORE_BREAKPOINT))
+	if (bd->debugger != NULL)
 	{
-		gtk_widget_hide (pass_entry);
-		gtk_widget_hide (pass_label);
-	}
-	if (!dma_debugger_queue_is_supported(bd->debugger, HAS_CONDITION_BREAKPOINT))
-	{
-		gtk_widget_hide (condition_entry);
-		gtk_widget_hide (condition_label);
+		if (!dma_debugger_queue_is_supported(bd->debugger, HAS_IGNORE_BREAKPOINT))
+		{	
+			gtk_widget_hide (pass_entry);
+			gtk_widget_hide (pass_label);
+		}
+		if (!dma_debugger_queue_is_supported(bd->debugger, HAS_CONDITION_BREAKPOINT))
+		{
+			gtk_widget_hide (condition_entry);
+			gtk_widget_hide (condition_label);
+		}
 	}
 	
 	if (bi == NULL)
@@ -1445,7 +1455,7 @@ breakpoints_dbase_edit_breakpoint (BreakpointsDBase *bd, BreakpointItem *bi)
 			uri = ianjuta_file_get_uri (IANJUTA_FILE (te), NULL);
 			line = ianjuta_editor_get_lineno (te, NULL);
 		}
-		//NULL uri ia ok here
+		//NULL uri is ok here
 		bi = breakpoint_item_new_from_uri (bd, uri, line, TRUE);
 		new_break = TRUE;
 	}
@@ -1455,24 +1465,21 @@ breakpoints_dbase_edit_breakpoint (BreakpointsDBase *bd, BreakpointItem *bi)
 		gtk_widget_hide (location_entry);
 		gtk_widget_show (location_label);
 	}
-		
-	if (bi->uri != NULL)
+	
+	if (bi->bp.type & IANJUTA_DEBUGGER_BREAKPOINT_ON_LINE)
 	{
-		if (bi->bp.line != 0)
-		{
-			// file and line
-			location = g_strdup_printf ("%s:%d", bi->bp.file, bi->bp.line);
-		}
-		else
-		{
-			// file and function
-			location = g_strdup_printf ("%s:%s", bi->bp.file, bi->bp.function);
-		}
-	}	
-	else if (bi->bp.address != 0)
+		/* file and line */
+		location = g_strdup_printf ("%s:%d", bi->bp.file, bi->bp.line);
+	}
+	else if (bi->bp.type & IANJUTA_DEBUGGER_BREAKPOINT_ON_FUNCTION)
 	{
-		// address
-		location = g_strdup_printf ("*%x", bi->bp.address);
+		/* file and function */
+		location = g_strdup_printf ("%s:%s", bi->bp.file, bi->bp.function);
+	}
+	else if (bi->bp.type & IANJUTA_DEBUGGER_BREAKPOINT_ON_ADDRESS)
+	{
+		/* address */
+		location = g_strdup_printf ("*%lx", bi->bp.address);
 	}
 
 	if (GTK_WIDGET_VISIBLE(location_entry))
@@ -1515,7 +1522,7 @@ breakpoints_dbase_edit_breakpoint (BreakpointsDBase *bd, BreakpointItem *bi)
 				
 				if (*new_location != '\0')
 				{
-					bi = breakpoint_item_new_from_string (bd, new_location, uri);
+					bi = breakpoint_item_new_from_string (bd, new_location, NULL);
 				}
 			}
 		}
@@ -1595,7 +1602,7 @@ on_toggle_breakpoint_activate (GtkAction * action, BreakpointsDBase *bd)
 	uri = ianjuta_file_get_uri (IANJUTA_FILE (te), NULL);
 	if (uri == NULL) return;     /* File not saved yet, it's not possible to put a breakpoint in it */
 	line = ianjuta_editor_get_lineno (te, NULL);
-	
+
 	/* Find corresponding breakpoint
 	 * Try to find right mark (it could have moved) first */
 	bi = breakpoints_dbase_find_breakpoint_from_mark (bd, te, line);
@@ -1785,9 +1792,9 @@ static GtkActionEntry actions_debugger_breakpoints[] = {
 	{
 		"ActionDmaClearAllBreakpoints",           /* Action name */
 		ANJUTA_STOCK_BREAKPOINT_CLEAR,            /* Stock icon, if any */
-		N_("C_lear All Breakpoints"),             /* Display label */
+		N_("R_emove All Breakpoints"),             /* Display label */
 		NULL,                                     /* short-cut */
-		N_("Delete all breakpoints"),             /* Tooltip */
+		N_("Remove all breakpoints"),             /* Tooltip */
 		G_CALLBACK (on_clear_all_breakpoints_activate)/* action callback */
 	},
 };		
@@ -1832,7 +1839,7 @@ on_breakpoints_button_press (GtkWidget * widget, GdkEventButton * bevent, Breakp
 	
 			gtk_tree_model_get (model, &iter, DATA_COLUMN, &bi, -1);
 			action = gtk_action_group_get_action (bd->debugger_group, "ActionDmaEnableDisableBreakpoint");
-			g_return_if_fail (action != NULL);
+			g_return_val_if_fail (action != NULL, FALSE);
 			if (bi->bp.enable)
 			{
 				label =	N_("Disable Breakpoint");
