@@ -15,14 +15,17 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #include <config.h>
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
+#include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 
+#include <glib/gi18n.h>
+
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-status.h>
 #include <libanjuta/anjuta-debug.h>
@@ -48,14 +51,14 @@ sort_wizards(gconstpointer wizard1, gconstpointer wizard2)
 	AnjutaPluginDescription* desc1 = (AnjutaPluginDescription*) wizard1;
 	AnjutaPluginDescription* desc2 = (AnjutaPluginDescription*) wizard2;
 	
-	if ((anjuta_plugin_description_get_string (desc1, "Wizard",
-												  "Title", &name1) ||
-			anjuta_plugin_description_get_string (desc1, "Anjuta Plugin",
-												  "Name", &name1)) &&
-		(anjuta_plugin_description_get_string (desc2, "Wizard",
-												  "Title", &name2) ||
-			anjuta_plugin_description_get_string (desc2, "Anjuta Plugin",
-												  "Name", &name2)))
+	if ((anjuta_plugin_description_get_locale_string (desc1, "Wizard",
+													  "Title", &name1) ||
+			anjuta_plugin_description_get_locale_string (desc1, "Anjuta Plugin",
+														 "Name", &name1)) &&
+		(anjuta_plugin_description_get_locale_string (desc2, "Wizard",
+													  "Title", &name2) ||
+			anjuta_plugin_description_get_locale_string (desc2, "Anjuta Plugin",
+														 "Name", &name2)))
 	{
 		return strcmp(name1, name2);
 	}
@@ -120,6 +123,19 @@ get_available_plugins_for_mime (AnjutaFileLoaderPlugin* plugin,
 												"SupportedMimeTypes",
 												mime_type,
 												NULL);
+	if (!plugin_descs);
+	{
+		gchar* supertype = gnome_vfs_get_supertype_from_mime_type (mime_type);
+		plugin_descs = anjuta_plugin_manager_query (plugin_manager,
+												"Anjuta Plugin",
+												"Interfaces", "IAnjutaFile",
+												"File Loader",
+												"SupportedMimeTypes",
+												supertype,
+												NULL);
+		g_free (supertype);
+	}
+	
 	return plugin_descs;
 }
 
@@ -182,13 +198,13 @@ open_with_dialog (AnjutaFileLoaderPlugin *plugin, const gchar *uri,
 		
 		name = NULL;
 		
-		anjuta_plugin_description_get_string (desc, "File Loader",
-											  "Title", &name);
+		anjuta_plugin_description_get_locale_string (desc, "File Loader",
+													 "Title", &name);
 		
 		if (!name)
 		{
-			anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
-												  "Name", &name);
+			anjuta_plugin_description_get_locale_string (desc, "Anjuta Plugin",
+														 "Name", &name);
 		}
 		if (!name)
 		{
@@ -532,18 +548,6 @@ on_open_activate (GtkAction *action, AnjutaFileLoaderPlugin *plugin)
 	gtk_widget_show (dlg);
 }
 
-static void
-on_new_activate (GtkAction *action, gpointer data)
-{
-	IAnjutaDocumentManager *docman;
-	docman = anjuta_shell_get_interface (ANJUTA_PLUGIN (data)->shell,
-										 IAnjutaDocumentManager, NULL);
-	if (docman)
-	{
-		ianjuta_document_manager_add_buffer (docman, "", "", NULL);
-	}
-}
-
 static void
 on_activate_wizard (GtkMenuItem *menuitem,
 					AnjutaFileLoaderPlugin *loader)
@@ -603,16 +607,16 @@ on_create_submenu (gpointer user_data)
 		
 		icon = NULL;
 		name = NULL;
-		if (anjuta_plugin_description_get_string (desc, "Wizard",
-												  "Title", &str) ||
-			anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
-												  "Name", &str))
+		if (anjuta_plugin_description_get_locale_string (desc, "Wizard",
+														 "Title", &str) ||
+			anjuta_plugin_description_get_locale_string (desc, "Anjuta Plugin",
+														 "Name", &str))
 		{
 			count++;
 			if (count < 10)
-				name = g_strdup_printf ("_%d. %s", count, str);
+				name = g_strdup_printf ("_%d. %s", count, N_(str));
 			else
-				name = g_strdup_printf ("%d. %s", count, str);
+				name = g_strdup_printf ("%d. %s", count, N_(str));
 			g_free (str);
 		}
 		if (anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
@@ -644,6 +648,7 @@ on_create_submenu (gpointer user_data)
 		if (name)
 		{
 			menuitem = gtk_image_menu_item_new_with_mnemonic (name);
+			g_free(name);
 			gtk_widget_show (menuitem);
 			g_object_set_data (G_OBJECT (menuitem), "__plugin_desc", desc);
 			g_signal_connect (G_OBJECT (menuitem), "activate",
@@ -771,14 +776,6 @@ pm_open_with (GtkMenuItem *menuitem, AnjutaFileLoaderPlugin *plugin)
 }
 
 static GtkActionEntry actions_file[] = {
-	{
-		"ActionFileNew",
-		GTK_STOCK_NEW,
-		N_("_New..."),
-		"<control>n",
-		N_("New empty editor."),
-		G_CALLBACK (on_new_activate)
-	},
 	{
 		"ActionFileOpen",
 		GTK_STOCK_OPEN,
@@ -853,12 +850,12 @@ create_open_with_submenu (AnjutaFileLoaderPlugin *plugin, GtkWidget *parentmenu,
 		
 		desc = (AnjutaPluginDescription *)(snode->data);
 		name = NULL;
-		anjuta_plugin_description_get_string (desc, "File Loader",
-											  "Title", &name);
+		anjuta_plugin_description_get_locale_string (desc, "File Loader",
+													 "Title", &name);
 		if (!name)
 		{
-			anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
-												  "Name", &name);
+			anjuta_plugin_description_get_locale_string (desc, "Anjuta Plugin",
+														 "Name", &name);
 		}
 		if (!name)
 		{
@@ -1150,9 +1147,6 @@ activate_plugin (AnjutaPlugin *plugin)
 								 GTK_ACTION (saction));
 	
 	/* Set short labels */
-	action = anjuta_ui_get_action (ui, "ActionGroupLoader", "ActionFileNew");
-	g_object_set (G_OBJECT (action), "short-label", _("New"),
-				  "is-important", TRUE, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupLoader", "ActionFileOpen");
 	g_object_set (G_OBJECT (action), "short-label", _("Open"),
 				  "is-important", TRUE, NULL);
