@@ -2,12 +2,12 @@ char *s = N_("Add C++ support:");
 char *s = N_("Add gtk-doc system:");
 char *s = N_("Add internationalization:");
 char *s = N_("Add shared library support:");
-char *s = N_("Adds c++ support to the project so that c++ source files can be built");
-char *s = N_("Adds supports for building shared libraries in your project");
-char *s = N_("Adds supports for internationalization so that your project can have translations in different languages");
+char *s = N_("Adds C++ support to the project so that C++ source files can be built");
+char *s = N_("Adds support for building shared libraries in your project");
+char *s = N_("Adds support for internationalization so that your project can have translations in different languages");
 char *s = N_("Author:");
 char *s = N_("Basic information");
-char *s = N_("Berkeley Software Distribution License(BSD)");
+char *s = N_("Berkeley Software Distribution License (BSD)");
 char *s = N_("Comma separated, other plugins that this plugin depends on. It could be either primary interface name or plugin location (library:class)");
 char *s = N_("Configure external packages");
 char *s = N_("Configure external packages:");
@@ -20,15 +20,14 @@ char *s = N_("Django Project information");
 char *s = N_("Email address:");
 char *s = N_("GCJ needs to know which class contains the main() function");
 char *s = N_("General Project Information");
-char *s = N_("General Project Infromation");
-char *s = N_("General Public License(GPL)");
+char *s = N_("General Public License (GPL)");
 char *s = N_("Give a package name that your project require. You may also mention what is the required version of the package. For example, 'libgnomeui-2.0' or 'libgnomeui-2.0 >= 2.2.0'");
 char *s = N_("Icon File:");
 char *s = N_("Icon file for the plugin");
 char *s = N_("Implement plugin interfaces");
 char *s = N_("Interface implemented by the plugin");
 char *s = N_("Interface:");
-char *s = N_("Lesser General Public License(LGPL)");
+char *s = N_("Lesser General Public License (LGPL)");
 char *s = N_("License");
 char *s = N_("Main Class:");
 char *s = N_("Main class");
@@ -63,7 +62,9 @@ char *s = N_("Require SDL_ttf library");
 char *s = N_("Require SDL_ttf:");
 char *s = N_("Select code license");
 char *s = N_("Shell values to watch");
-char *s = N_("Use pkg-config to add library supports from other packages");
+char *s = N_("Use libglade for the UI");
+char *s = N_("Use pkg-config to add library support from other packages");
+char *s = N_("Use the libglade-2.0 library to load the glade interface file at runtime");
 char *s = N_("Value Name:");
 char *s = N_("Values to watch");
 char *s = N_("Version:");
