@@ -23,6 +23,7 @@
 
 #include <gnome.h>
 #include <glade/glade.h>
+#include <libgnomevfs/gnome-vfs.h>
 
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/anjuta-plugin.h>
@@ -408,10 +409,17 @@ search_and_replace (void)
 									(sr->docman, NULL));
 
 						if (IANJUTA_INDICABLE (fb->te))
-					/* end-location is correct for sourceview, 1-too-big for scintilla */
-						ianjuta_indicable_set (IANJUTA_INDICABLE(fb->te),  
-						                       mi->pos, mi->pos + mi->len,  
-					            					IANJUTA_INDICABLE_IMPORTANT, NULL);
+						{
+							IAnjutaIterable *start_pos, *end_pos;
+							/* end-location is correct for sourceview, 1-too-big for scintilla */
+							start_pos = ianjuta_editor_get_position_from_offset (fb->te, mi->pos, NULL);
+							end_pos = ianjuta_editor_get_position_from_offset (fb->te, mi->pos + mi->len, NULL);
+							ianjuta_indicable_set (IANJUTA_INDICABLE(fb->te),
+												   start_pos, end_pos,
+												   IANJUTA_INDICABLE_IMPORTANT, NULL);
+							g_object_unref (start_pos);
+							g_object_unref (end_pos);
+						}
 						break;
 
 					case SA_BOOKMARK:
@@ -443,13 +451,13 @@ search_and_replace (void)
 							if (fb->te)
 								ianjuta_editor_goto_line (fb->te, mi->line, NULL);
 							else
-								fb->te = ianjuta_document_manager_goto_file_line_mark
-									(sr->docman, fb->path, mi->line, FALSE, NULL);
+								fb->te = ianjuta_document_manager_goto_uri_line_mark
+									(sr->docman, fb->uri, mi->line, FALSE, NULL);
 							found_line = mi->line;
 						}
 						{
-							IAnjutaIterable* start = ianjuta_editor_get_cell_iter (fb->te, mi->pos, NULL);
-							IAnjutaIterable* end = ianjuta_editor_get_cell_iter (fb->te, mi->pos + mi->len, NULL);
+							IAnjutaIterable* start = ianjuta_editor_get_position_from_offset (fb->te, mi->pos, NULL);
+							IAnjutaIterable* end = ianjuta_editor_get_position_from_offset (fb->te, mi->pos + mi->len, NULL);
 							ianjuta_editor_selection_set(IANJUTA_EDITOR_SELECTION (fb->te), 
 														 start,
 														 end,
@@ -469,15 +477,15 @@ search_and_replace (void)
 							if (fb->te)
 								ianjuta_editor_goto_line (fb->te, mi->line, NULL);
 							else
-								fb->te = ianjuta_document_manager_goto_file_line_mark
-									(sr->docman, fb->path, mi->line, FALSE, NULL);
+								fb->te = ianjuta_document_manager_goto_uri_line_mark
+									(sr->docman, fb->uri, mi->line, FALSE, NULL);
 							found_line = mi->line;
 							}
 
 						if (!interactive)
 						{
-							IAnjutaIterable* start = ianjuta_editor_get_cell_iter (fb->te, mi->pos - offset, NULL);
-							IAnjutaIterable* end = ianjuta_editor_get_cell_iter (fb->te, mi->pos - offset + mi->len, NULL);
+							IAnjutaIterable* start = ianjuta_editor_get_position_from_offset (fb->te, mi->pos - offset, NULL);
+							IAnjutaIterable* end = ianjuta_editor_get_position_from_offset (fb->te, mi->pos - offset + mi->len, NULL);
 							ianjuta_editor_selection_set(IANJUTA_EDITOR_SELECTION (fb->te), 
 														 start,
 														 end,
@@ -505,8 +513,8 @@ search_and_replace (void)
 								ch = NULL;
 						}
 							{
-								IAnjutaIterable* start = ianjuta_editor_get_cell_iter (fb->te, mi->pos - os, NULL);
-								IAnjutaIterable* end = ianjuta_editor_get_cell_iter (fb->te, mi->pos + mi->len - os, NULL);
+								IAnjutaIterable* start = ianjuta_editor_get_position_from_offset (fb->te, mi->pos - os, NULL);
+								IAnjutaIterable* end = ianjuta_editor_get_position_from_offset (fb->te, mi->pos + mi->len - os, NULL);
 								ianjuta_editor_selection_set(IANJUTA_EDITOR_SELECTION (fb->te),  
 															 start,														 
 															 end,
@@ -540,8 +548,8 @@ search_and_replace (void)
 						}
 						else
 						{
-							IAnjutaIterable* start = ianjuta_editor_get_cell_iter (fb->te, mi->pos - offset, NULL);
-							IAnjutaIterable* end = ianjuta_editor_get_cell_iter (fb->te, mi->pos + mi->len - offset, NULL);
+							IAnjutaIterable* start = ianjuta_editor_get_position_from_offset (fb->te, mi->pos - offset, NULL);
+							IAnjutaIterable* end = ianjuta_editor_get_position_from_offset (fb->te, mi->pos + mi->len - offset, NULL);
 							ianjuta_editor_selection_set(IANJUTA_EDITOR_SELECTION (fb->te),  
 														 start,
 														 end,
@@ -680,6 +688,7 @@ on_message_clicked (GObject* object, gchar* message, gpointer data)
 {
 	gchar *ptr, *ptr2;
 	gchar *path, *nline;
+	gchar *uri;
 	gint line;
 		
 	if (!(ptr = g_strstr_len(message, strlen(message), ":")) )
@@ -691,8 +700,10 @@ on_message_clicked (GObject* object, gchar* message, gpointer data)
 		return FALSE;
 	nline = g_strndup(ptr, ptr2 - ptr);
 	line = atoi(nline);
-							
-	ianjuta_document_manager_goto_file_line_mark (sr->docman, path, line, TRUE, NULL);  
+	
+	uri = gnome_vfs_get_uri_from_local_path (path);  
+	ianjuta_document_manager_goto_uri_line_mark (sr->docman, uri, line, TRUE, NULL);
+	g_free(uri);
 	g_free(path);
 	g_free(nline);
 	return FALSE;
@@ -1011,18 +1022,15 @@ search_start_over (SearchDirection direction)
 	IAnjutaEditor *te = NULL;
 	if (IANJUTA_IS_EDITOR(doc))
 		te = IANJUTA_EDITOR(doc);
-	long length;
 	
 	if (te)
 	{
-		length = ianjuta_editor_get_length(te, NULL);;
-	
 		if (direction != SD_BACKWARD)
 			/* search from doc start */
-			ianjuta_editor_goto_position(te, 0, NULL);
+			ianjuta_editor_goto_start (te, NULL);
 		else
 			/* search from doc end */
-			ianjuta_editor_goto_position (te, length, NULL);
+			ianjuta_editor_goto_end (te, NULL);
 	}
 }
 
@@ -1087,7 +1095,8 @@ nb_results_alert(gint nb)
 {
 	GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW (sg->dialog),
 				GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
-		        	_("%d matches have been replaced."), nb);
+		        	ngettext("%d match has been replaced.",
+							 "%d matches have been replaced.", nb), nb);
 	g_signal_connect(G_OBJECT(dialog), "key-press-event",
 			G_CALLBACK(on_search_dialog_key_press_event), NULL);
 	gtk_dialog_run(GTK_DIALOG(dialog));
