@@ -44,7 +44,6 @@
 #include <libanjuta/anjuta-debug.h>
 
 #include "anjuta-app.h"
-#include "anjuta-callbacks.h"
 #include "anjuta-actions.h"
 #include "about.h"
 
@@ -626,7 +625,7 @@ anjuta_app_instance_init (AnjutaApp *app)
 										G_N_ELEMENTS (menu_entries_view),
 										GETTEXT_PACKAGE, TRUE, app);
 	anjuta_ui_add_toggle_action_group_entries (app->ui, "ActionGroupToggleView",
-										_("Toggle View"),
+										_("View"),
 										menu_entries_toggle_view,
 										G_N_ELEMENTS (menu_entries_toggle_view),
 										GETTEXT_PACKAGE, TRUE, app);
